
/**
 * @param {string} path
 * @returns {PIXI.Texture}
 */
function tex(path) {
  let fullPath = `${path}.png`;
  let res = app.loader.resources[fullPath];
  if (!res) {
    throw new Error(`Missing texture resource: ${fullPath}`);
  }
  return res.texture;
}

/**
 * @param {string} path
 * @returns {any}
 */
function jsonRes(path) {
  let fullPath = `${path}.json`;
  let res = app.loader.resources[fullPath];
  if (!res) {
    throw new Error(`Missing json resource: ${fullPath}`);
  }
  return res.data;
}

/**
 * @param {string} path
 * @returns {any}
 */
function json5Res(path) {
  let fullPath = `${path}.json5`;
  let res = app.loader.resources[fullPath];
  if (!res) {
    throw new Error(`Missing json5 resource: ${fullPath}`);
  }
  if (typeof res.data === "string") {
    // in case it was valid JSON (not 5) and pixi
    // already parsed it? idk.
    return JSON5.parse(res.data);
  } else {
    return res.data;
  }
}

/**
 * generates random identifier
 * @return {string}
 */
function generateID() {
  // Math.random should be unique because of its seeding algorithm.
  // Convert it to base 36 (numbers + letters), and grab the first 9 characters
  // after the decimal.
  return '_' + Math.random().toString(36).substr(2, 9);
};